@@ -7,6 +7,7 @@ mod use_mount;
 mod use_timeout;
 mod use_toggle;
 mod use_unmount;
+mod use_update;
 
 pub use use_counter::*;
 pub use use_effect_once::*;
@@ -17,3 +18,4 @@ pub use use_mount::*;
 pub use use_timeout::*;
 pub use use_toggle::*;
 pub use use_unmount::*;
+pub use use_update::*;
