@@ -4,7 +4,7 @@ use yew::use_state;
 /// A hook returns a function that forces component to re-render when called.
 ///
 /// # Example
-/// 
+///
 /// ```rust
 /// # use yew::prelude::*;
 /// #
@@ -28,10 +28,7 @@ use yew::use_state;
 pub fn use_update() -> Rc<impl Fn()> {
     let state = use_state(|| 0);
 
-    {
-        let state = state.clone();
-        Rc::new(move || {
-            state.set((*state + 1) % 1_000_000);
-        })
-    }
+    Rc::new(move || {
+        state.set((*state + 1) % 1_000_000);
+    })
 }
